@@ -1,15 +1,15 @@
 import shutil
 import subprocess
 from pathlib import Path
-from typing import Dict, List, Optional
+from typing import Dict, List
 
-from . import logger
-from .apt import DebianRepositoryPackage, sync_list_repository_packages
-from .exceptions import Ops2debGeneratorError, Ops2debGeneratorScriptError
-from .fetcher import FetchResult, fetch_remote_files
-from .parser import Blueprint, HereDocument, SourceDestinationStr, extend
-from .templates import environment
-from .utils import working_directory
+from ops2deb import logger
+from ops2deb.apt import DebianRepositoryPackage, sync_list_repository_packages
+from ops2deb.exceptions import Ops2debGeneratorError, Ops2debGeneratorScriptError
+from ops2deb.fetcher import FetchResult, fetch_remote_files
+from ops2deb.parser import Blueprint, HereDocument, SourceDestinationStr, extend
+from ops2deb.templates import environment
+from ops2deb.utils import working_directory
 
 
 def _format_command_output(output: str) -> str:
@@ -72,9 +72,16 @@ class SourcePackage:
                 f"Source {str(source)} is not a file nor a directory"
             )
 
+    def _render_string(self, string: str) -> str:
+        return self.blueprint.render_string(
+            string,
+            src=self.source_directory,
+            debian=self.debian_directory,
+        )
+
     def _install_files(self) -> None:
         for entry in self.blueprint.install:
-            destination = Path(self.blueprint.render_string(entry.destination))
+            destination = Path(self._render_string(entry.destination))
             if (
                 destination.is_absolute() is True
                 and destination.is_relative_to(self.package_directory) is False
@@ -90,10 +97,8 @@ class SourcePackage:
                 self._install_source_destination_str(entry, destination)
 
     def _run_script(self) -> None:
-        # run script
-        for line in self.blueprint.render_script(
-            src=self.source_directory, debian=self.debian_directory
-        ):
+        for line in self.blueprint.script:
+            line = self._render_string(line)
             logger.info(f"$ {line}")
             result = subprocess.run(line, shell=True, capture_output=True)
             if stdout := result.stdout.decode():
@@ -104,7 +109,7 @@ class SourcePackage:
                 raise Ops2debGeneratorScriptError
 
     def generate(self, fetch_results: Dict[str, FetchResult]) -> None:
-        fetch_result: Optional[FetchResult] = None
+        fetch_result: FetchResult | None = None
         if self.remote_file is not None:
             fetch_result = fetch_results.get(self.remote_file.url, None)
             if fetch_result is None:
@@ -161,8 +166,8 @@ def filter_already_published_packages(
 def generate(
     blueprints: List[Blueprint],
     output_directory: Path,
-    debian_repository: Optional[str] = None,
-    only_names: Optional[List[str]] = None,
+    debian_repository: str | None = None,
+    only_names: List[str] | None = None,
 ) -> List[SourcePackage]:
     # each blueprint can yield multiple source packages, one per supported arch
     packages = [SourcePackage(b, output_directory) for b in extend(blueprints)]
